module DegenzGame.Shared

open System
open DSharpPlus
open DSharpPlus.Entities
open DSharpPlus.SlashCommands

type ActionClass =
    | Network
    | Exploit
    | Penetration

type Weapon =
    | Virus = 0
    | Ransom = 1
    | Worm = 2
    | DDos = 3
    | Crack = 4
    | Injection = 5

type Shield =
    | Firewall = 0
    | PortScan = 1
    | Encryption = 2
    | Hardening = 4
    | Sanitation = 5
    | Cypher = 3

let getClass = function
    | 0 | 1 -> Network
    | 2 | 3 -> Exploit
    | 4 | _ -> Penetration

type HackResult =
    | Strong
    | Weak

[<CLIMutable>]
type DiscordPlayer = {
    Id : uint64
    Name : string
}

[<CLIMutable>]
type Attack = {
    HackType : Weapon
    Target : DiscordPlayer
    Timestamp : DateTime
}

[<CLIMutable>]
type Defense = {
    DefenseType : Shield
    Timestamp : DateTime
}

[<CLIMutable>]
type Player = {
    DiscordId : uint64
    Name : string
    Weapons : Weapon array
    Shields : Shield array
    Attacks : Attack array
    Defenses : Defense array
    Bank : single
}

let createSimpleResponseAsync msg (ctx : InteractionContext) =
    async {
        let builder = DiscordInteractionResponseBuilder()
        builder.Content <- msg
        builder.AsEphemeral true |> ignore
        do! ctx.CreateResponseAsync(InteractionResponseType.ChannelMessageWithSource, builder)
            |> Async.AwaitTask
    }

let notYetAHackerMsg = createSimpleResponseAsync "You are not currently a hacker, first use the /redpill command to become one"